# Topsis-Sahil-102003466
This file takes 5 arguments from the user
1->python file name
2->Input file name i.e of the dataset
3->An array of Weights For example:'1,1,1,0,0' 
4->An array of Impact For example:'+,-,+,-,+'
5->The file in which the user want to store the result

## Installation
```pip install Topsis-Sahil-102003466```

## How to use it?
Open terminal and type Topsis-Sahil-102003466 and then give the input according to the requirements

## License

© 2023 Sahil Kadiyan

This repository is licensed under the MIT license

